Book class

Constructors

Book({required String bookNumber, required List<BookData> book, required int hadithStartNumber, required int hadithEndNumber, required int numberOfHadith})
Book.fromJson(Map<String, dynamic> json)
factory

Properties

book → List<BookData>
final
bookNumber → String
final
hadithEndNumber → int
final
hadithStartNumber → int
final
hashCode → int
The hash code for this object.
no setterinherited
numberOfHadith → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited