CollectionData class

Constructors

CollectionData({required String lang, required String title, required String shortIntro})
CollectionData.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lang → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortIntro → String
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited