Grade class

Constructors

Grade({String? gradedBy, required String grade})
Grade.fromJson(Map<String, dynamic> json)
factory

Properties

grade → String
final
gradedBy → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited