Hadith class

Constructors

Hadith({required String collection, required String bookNumber, required String chapterId, required String hadithNumber, required List<HadithData> hadith})
Hadith.fromJson(Map<String, dynamic> json)
factory

Properties

bookNumber → String
final
chapterId → String
final
collection → String
final
hadith → List<HadithData>
final
hadithNumber → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited