HadithCollection class

Constructors

HadithCollection({required String name, required bool hasBooks, required bool hasChapters, required List<CollectionData> collection, required int totalHadith, required int totalAvailableHadith})
HadithCollection.fromJson(Map<String, dynamic> json)
factory

Properties

collection → List<CollectionData>
final
hasBooks → bool
final
hasChapters → bool
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalAvailableHadith → int
final
totalHadith → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited