HadithData class

Constructors

HadithData({required String lang, required String chapterNumber, required String chapterTitle, required int urn, required String body, required List<Grade> grades})
HadithData.fromJson(Map<String, dynamic> json)
factory

Properties

body → String
final
chapterNumber → String
final
chapterTitle → String
final
grades → List<Grade>
final
hashCode → int
The hash code for this object.
no setterinherited
lang → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urn → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited